# torskel
Python package with skeleton of the base Tornado application.

Contains basic functions for logging, asynchronous redis, support for reactJS and asynchronous http request

Only Python 3.7+

For redis support  - you need install aioredis >=1.0.0

For reactJs support you need install jinja2

For CurlAsyncHTTPClient support - you need install pycurl

For MongoDB support - you need install motor

For more information see examples
